;; Generated package description from dicom.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "dicom" "0.5.0.20250512.155532" "DICOM viewer - Digital Imaging & Communications in Medicine" '((emacs "28.1") (compat "30")) :commit "df63045afc0740e4af25bd7f8b6b2e21c92cd987" :authors '(("Daniel Mendler" . "mail@daniel-mendler.de")) :maintainer '("Daniel Mendler" . "mail@daniel-mendler.de") :keywords '("multimedia" "hypermedia" "files") :url "https://github.com/minad/dicom")
